@@ -1,4 +1,5 @@
 """Console script for baseten."""
+import configparser
 import functools
 import json
 import logging
@@ -6,11 +7,9 @@ import sys
 from urllib.parse import urlparse
 
 import click
-import keyring
 
 from baseten.common import api
-from baseten.common.core import KEYRING_SERVICE_NAME
-from baseten.common.settings import CONFIG_FILE_PATH
+from baseten.common.settings import read_config, set_config_value
 from baseten.common.util import setup_logger
 
 logger = logging.getLogger(__name__)
@@ -19,8 +18,10 @@ logger = logging.getLogger(__name__)
 def ensure_login(func):
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
-        api_key = keyring.get_password(KEYRING_SERVICE_NAME, username=None)
-        if not api_key:
+        config = read_config()
+        try:
+            config.get('api', 'api_key')
+        except configparser.NoOptionError:
             click.echo('You must first run the `baseten login` cli command.')
             sys.exit()
         result = func(*args, **kwargs)
@@ -39,15 +40,14 @@ def configure(server_url):
     if not _is_valid_url(server_url):
         click.echo('That is not a valid URL.')
         return
-    with open(CONFIG_FILE_PATH, 'w') as config_file:
-        config_file.write(server_url)
+    set_config_value('api', 'url_base', server_url)
     click.echo('Saved server URL.')
 
 
 @cli_group.command()
 @click.option('--api_key', prompt='BaseTen API key', hide_input=True)
 def login(api_key):
-    keyring.set_password(KEYRING_SERVICE_NAME, username=None, password=api_key)
+    set_config_value('api', 'api_key', api_key)
     click.echo('Saved API key.')
 
 
@@ -58,18 +58,10 @@ def models():
     click.echo('Your models:\n{}'.format(json.dumps(user_models, indent=4)))
 
 
-@cli_group.command()
-@click.option('--model_id', prompt='The model whose versions are being retrieved')
-@ensure_login
-def model_versions(model_id):
-    user_models = api.models_versions(model_id)
-    click.echo('Your model\'s versions:\n{}'.format(json.dumps(user_models, indent=4)))
-
-
 def _is_valid_url(url: str) -> bool:
     try:
         result = urlparse(url)
-        return all([result.scheme, result.netloc, result.path])
+        return all([result.scheme, result.netloc])
     except ValueError:
         return False
 
