@@ -273,6 +273,148 @@ def register_data_for_model(api_key, s3_key, model_version_id, data_name):
     return resp['data']['create_sample_data_file']
 
 
+@with_api_key
+def create_artifact(
+    api_key: str,
+    s3_key: str,
+    name: str,
+    description: str = None,
+    model_id: str = None,
+    model_version_id: str = None,
+):
+    # encode for None/null
+    description = base64_encoded_json_str(description)
+    model_id = base64_encoded_json_str(model_id)
+    model_version_id = base64_encoded_json_str(model_version_id)
+
+    query_string = f'''
+    mutation {{
+        create_artifact(
+            name: "{name}",
+            s3_key: "{s3_key}",
+            encoded_description: "{description}",
+            encoded_model_id: "{model_id}",
+            encoded_model_version_id: "{model_version_id}"
+        )
+        {{
+            artifact_id: id,
+            name,
+            description
+        }}
+    }}
+    '''
+    resp = _post_graphql_query(api_key, query_string)
+    return resp['data']['create_artifact']
+
+
+@with_api_key
+def create_artifact_link(
+    api_key: str,
+    artifact_id: str,
+    model_id: str = None,
+    model_version_id: str = None,
+):
+    # encode for None/null
+    model_id = base64_encoded_json_str(model_id)
+    model_version_id = base64_encoded_json_str(model_version_id)
+
+    query_string = f'''
+    mutation {{
+        link_artifact(
+            id: "{artifact_id}",
+            encoded_model_id: "{model_id}",
+            encoded_model_version_id: "{model_version_id}"
+        )
+        {{
+            id
+        }}
+    }}
+    '''
+    resp = _post_graphql_query(api_key, query_string)
+    return resp['data']['link_artifact']
+
+
+@with_api_key
+def artifact_url(
+    api_key: str,
+    artifact_id: str,
+):
+    query_string = f'''{{
+        artifact(
+            id: "{artifact_id}",
+        )
+        {{
+            id, url
+        }}
+    }}
+    '''
+    resp = _post_graphql_query(api_key, query_string)
+    return resp['data']['artifact']['url']
+
+
+@with_api_key
+def artifact_links(
+    api_key: str,
+    artifact_id: str,
+):
+    query_string = f'''{{
+        artifact(
+            id: "{artifact_id}",
+        )
+        {{
+            model_ids: oracle_ids
+            model_version_ids: oracle_version_ids
+        }}
+    }}
+    '''
+    resp = _post_graphql_query(api_key, query_string)
+    return resp['data']['artifact']
+
+
+@with_api_key
+def model_linked_artifacts(
+    api_key: str,
+    model_id: str,
+):
+    query_string = f'''{{
+        model(
+            id: "{model_id}",
+        )
+        {{
+            artifacts {{
+                artifact_id: id,
+                name,
+                description
+            }}
+        }}
+    }}
+    '''
+    resp = _post_graphql_query(api_key, query_string)
+    return resp['data']['model']['artifacts']
+
+
+@with_api_key
+def model_version_linked_artifacts(
+    api_key: str,
+    model_version_id: str,
+):
+    query_string = f'''{{
+        model_version(
+            id: "{model_version_id}",
+        )
+        {{
+            artifacts {{
+                artifact_id: id,
+                name,
+                description
+            }}
+        }}
+    }}
+    '''
+    resp = _post_graphql_query(api_key, query_string)
+    return resp['data']['model_version']['artifacts']
+
+
 @with_api_key
 def predict_for_model(api_key, model_id: str, inputs: list, metadata: List[Dict] = None) -> List[List]:
     """Call the model's predict given the input json.
