@@ -74,3 +74,7 @@ class Semver(Enum):
     MAJOR = 'MAJOR'
     MINOR = 'MINOR'
     PATCH = 'PATCH'
+
+
+MODEL_FILENAME = 'model'
+ARTIFACT_FILENAME = 'artifact'
