@@ -25,9 +25,11 @@ from requests_toolbelt import MultipartEncoder, MultipartEncoderMonitor
 from tqdm import tqdm
 
 import baseten
-from baseten.baseten_deployed_model import BasetenDeployedModel
+from baseten.baseten_deployed_model import (BasetenArtifact,
+                                            BasetenDeployedModel)
 from baseten.common import api
-from baseten.common.core import (FrameworkNotSupportedError,
+from baseten.common.core import (ARTIFACT_FILENAME, MODEL_FILENAME,
+                                 FrameworkNotSupportedError,
                                  ModelClassImplementationError,
                                  ModelFilesMissingError, ModelInputShapeError,
                                  ModelNotSupportedError, Semver,
@@ -88,7 +90,7 @@ def deploy_model(serialized_model: IO[Any],
     logger.info('👽 👋 Making contact with BaseTen 👋 👽')
 
     file_ext = _model_ext_from_framework(model_framework)
-    model_key = _upload_model(serialized_model, file_ext)
+    model_key = _upload_file(serialized_model, file_ext, MODEL_FILENAME)
     model_info = _exists_model(model_name, baseten.working_model_id, api.models)
     if not model_info:
         logger.debug('No model found with provided name/id.')
@@ -442,6 +444,52 @@ def build_baseten_custom_scaffold(
     return b10_scaffold
 
 
+def _tar_a_list_of_files(list_of_files: List[str]) -> tempfile.NamedTemporaryFile:
+    temp_file = tempfile.NamedTemporaryFile(suffix='.tgz')
+    with tarfile.open(temp_file.name, 'w:gz') as tar:
+        for file in list_of_files:
+            tar.add(file)
+    temp_file.file.seek(0)
+    return temp_file
+
+
+@raises_api_error
+def create_artifact(
+    name: str,
+    list_of_files: List[str],
+    description: str = None,
+    model_id: str = None,
+    model_version_id: str = None,
+):
+    """Create an artifact in the BaseTen backend to track
+
+        Args:
+            name (str): The name of the artifact to be created.
+            list_of_files (List[str]): A list of files to be uploaded.
+            description (str, optional): An optional description of the artifact
+            model_id (str, optional): A model_id to associate with the artifact
+            model_version_id (str, optional): A model_version_id to associate with the artifact
+        Returns:
+            BasetenArtifact
+
+        Raises:
+            ApiError: If there was an error communicating with the server.
+        """
+    logger.info(f'Serializing {Fore.BLUE}{name}{Style.RESET_ALL} artifact.')
+    artifact_tgz = _tar_a_list_of_files(list_of_files)
+    logger.info('Making contact with BaseTen 👋 👽')
+    s3_key = _upload_file(artifact_tgz, 'tgz', ARTIFACT_FILENAME)
+    artifact_resp = api.create_artifact(
+        s3_key,
+        name,
+        description=description,
+        model_id=model_id,
+        model_version_id=model_version_id
+    )
+    logger.info(f'Successfully stored {Fore.BLUE}{name}{Style.RESET_ALL} artifact with id {artifact_resp["id"]}.')
+    return BasetenArtifact(**artifact_resp)
+
+
 @raises_api_error
 def deploy_baseten_scaffold(
     b10_scaffold: AbstractModelScaffoldDefinition,
@@ -468,7 +516,7 @@ def deploy_baseten_scaffold(
     model_info = _exists_model(model_name, baseten.working_model_id, api.models)
 
     logger.info('Making contact with BaseTen 👋 👽')
-    s3_key = _upload_model(temp_file, 'tgz')
+    s3_key = _upload_file(temp_file, 'tgz', MODEL_FILENAME)
     if not model_info:
         model_version_json = api.create_model_from_scaffold(
             model_name,
@@ -596,11 +644,11 @@ def build_and_deploy_baseten_custom_scaffold(
     )
 
 
-def _upload_model(serialized_model: IO, file_ext: str) -> str:
+def _upload_file(serialize_file: IO, file_ext: str, file_name: str) -> str:
     """Uploads the serialized model to the appropriate environment
 
     Args:
-        serialized_model (file): A file-like object that is the serialized representation of the model object.
+        serialize_file (file): A file-like object that is the serialized representation of the model object.
         file_ext (str): The file extension for the saved model
 
     Returns:
@@ -610,14 +658,14 @@ def _upload_model(serialized_model: IO, file_ext: str) -> str:
         RequestException: If there was an error communicating with the server.
     """
 
-    model_file_name = f'model.{file_ext}'
+    model_file_name = f'{file_name}.{file_ext}'
     signed_s3_upload_post = api.signed_s3_upload_post(model_file_name)
     logger.debug(f'Signed s3 upload post:\n{json.dumps(signed_s3_upload_post, indent=4)}')
 
     # Upload the serialized model to S3
     form_fields = signed_s3_upload_post['form_fields']
     form_fields['AWSAccessKeyId'] = form_fields.pop('aws_access_key_id')  # S3 expects key name AWSAccessKeyId
-    form_fields['file'] = (model_file_name, serialized_model)
+    form_fields['file'] = (model_file_name, serialize_file)
     logger.info('🚀 Uploading model to BaseTen 🚀')
     encoder = MultipartEncoder(fields=form_fields)
     encoder_len = encoder.len
