@@ -126,37 +126,3 @@ def parse_requirements_file(requirements_file: str) -> dict:
                 pass
 
     return name_to_req_str
-
-
-def pip_freeze():
-    """
-    This spawns a subprocess to do a pip freeze programmatically. pip is generally not supported as an API or threadsafe
-
-    Returns: The result of a `pip freeze`
-
-    """
-    stream = os.popen('pip freeze -qq')
-    this_env_requirements = [line.strip() for line in stream.readlines()]
-
-    return this_env_requirements
-
-
-def _get_entries_for_packages(list_of_requirements, desired_requirements):
-    name_to_req_str = {}
-    for req_name in desired_requirements:
-        for full_req_str in list_of_requirements:
-            if req_name == full_req_str.split('==')[0]:
-                name_to_req_str[req_name] = full_req_str
-    return name_to_req_str
-
-
-def infer_sklearn_packages():
-    return _get_entries_for_packages(pip_freeze(), SKLEARN_REQ_MODULE_NAME)
-
-
-def infer_tensorflow_packages():
-    return _get_entries_for_packages(pip_freeze(), TENSORFLOW_REQ_MODULE_NAME)
-
-
-def infer_pytorch_packages():
-    return _get_entries_for_packages(pip_freeze(), PYTORCH_REQ_MODULE_NAME)
